<?php
/**
 * @file
 * Display style plugin for Views that renders rows as a timetable.
 */

/**
 * Style plugin to display a timetable.
 */
class field_timetable_style_plugin extends views_plugin_style {

  /**
   * Set default options
   */
  function option_definition() {
    $options = parent::option_definition();
    
    $options['mintime'] = 9;
    $options['maxtime'] = 18;
    $options['slotminutes'] = 60;
    $options['color'] = '#000000';
    $options['textcolor'] = '#FFFFFF';
    
    return $options;
  }

  // Create the options form.
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    // check if timetable field
    $timetable_fields = array();
    $title_fields = array();
    $color_field = array();
    
    // default color settings.
    $color_field['random'] = t('Random');
    $color_field['manual'] = t('Manual');
    
    // Build a list of all fields.
    $options = array();
    foreach ($this->display->handler->get_handlers('field') as $field => $handler) {
      
      $title_fields[$field] = $handler->label();
      $color_field[$field] = $handler->label();
      
      // search for timetable field
      if ($handler->field_info['type'] == 'field_timetable_timetable') {
        $timetable_fields[$field] = $handler->label();
      }

    }
    
    if (empty($options)) {
      $options[''] = t('No available fields');
    }

    if (empty($timetable_fields)) {
      $options[''] = t('No timetable fields');
    }
    
    // Title field.
    $form['settings']['timetable_field'] = array(
      '#type' => 'select',
      '#title' => t('timetable_field'),
      '#options' => $timetable_fields,
      '#default_value' => $this->options['timetable_field'],
      '#multiple' => TRUE,
      '#parents' => array(
        'style_options',
        'timetable_field',
      ),
    );

    // Title field.
    $form['settings']['title_field'] = array(
      '#type' => 'select',
      '#title' => t('title_field'),
      '#options' => $title_fields,
      '#default_value' => $this->options['title_field'],
      '#multiple' => TRUE,
      '#parents' => array(
        'style_options',
        'title_field',
      ),
    );
    
    // Color field.
    $form['settings']['color_field'] = array(
      '#type' => 'select',
      '#title' => t('Color Field'),
      '#options' => $color_field,
      '#default_value' => $this->options['color_field'],
      '#parents' => array(
        'style_options',
        'color_field',
      ),
    );

    $form['settings']['color_field_manual'] = array(
      '#type' => 'textfield',
      '#title' => t('Manual Color'),
      '#default_value' => $this->options['color_field_manual'],
      '#parents' => array(
        'style_options',
        'color_field_manual',
      ),
    );
    
    $options = array();
    for ($i=0 ; $i < 24 ; $i++) {
      $options[$i] = $i . ':00';
    }
    $form['settings']['mintime'] = array(
      '#type' => 'select',
      '#title' => t('mintime'),
      '#options' => $options,
      '#default_value' => $this->options['mintime'],
      '#parents' => array(
        'style_options',
        'mintime',
      ),
    );
    
    $options = array();
    for ($i=1 ; $i <= 24 ; $i++) {
      $options[$i] = $i . ':00';
    }
    $form['settings']['maxtime'] = array(
      '#type' => 'select',
      '#title' => t('maxtime'),
      '#options' => $options,
      '#default_value' => $this->options['maxtime'],
      '#parents' => array(
        'style_options',
        'maxtime',
      ),
    );

    $options = array(15 => t('15 min'), 30 => t('30 min'), 60 => t('60 min'));
    $form['settings']['slotminutes'] = array(
      '#type' => 'select',
      '#title' => t('slotminutes'),
      '#options' => $options,
      '#default_value' => $this->options['slotminutes'],
      '#parents' => array(
        'style_options',
        'slotminutes',
      ),
    );    
    
  }
  
  // Override the render functionality.
  function render() {
    
    $color_field = $this->options['color_field'];
    $title_fields = $this->options['title_field'];
    $timetable_fields = $this->options['timetable_field'];
    
    if (empty($this->row_plugin)) {
      vpr('views_plugin_style_default: Missing row plugin');
      return;
    }
    
    $rows = array();
    
    // for each result
    foreach ($this->view->result as $row_index => $row) {
      
      // Build title.
      $titles = array();
      foreach ($title_fields as $title_field) {
        $title_field = 'field_' . $title_field;
        $temp = $row->$title_field;
        $titles[] = $temp[0]['rendered']['#markup'];
      }
      if (empty($titles)) {
        $title = $row->node_title;
      } else {
        $title = implode(', ',$titles);
      }
      
      if (empty($title)) {
        $title = ' ';
      }
      
      // Build color
      switch ($color_field) {
        case 'manual':
          $color = '#B56B43';
          break;
        case 'random':
          $color = '#B56B43';
          break;
        default:  
          $color = 'field_' . $color_field;
          $color = $row->$color;
          $color = $color[0]['raw']['taxonomy_term']->field_service_color[LANGUAGE_NONE][0]['rgb'];
      }
         
      // for each row
      foreach ($timetable_fields as $timetable_field) {
        $timetable_field = 'field_' . $timetable_field;
        foreach ($row->$timetable_field as $field_index => $field) {
          $field['raw']['title'] = $title;
          $field['raw']['color'] = $color;
          $rows[] = $field['raw'];
        }
      }
      
    }
    
    $output = theme('field_timetable_view',
      array(
        'view' => $this->view,
        'options' => $this->options,
        'rows' => $rows
      )
    );
    unset($this->view->row_index);
    return $output;
  }

}
